@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: keys
 version: 3.11
-id: keys-3.11-ade7d136d0c3ee7dfe52cac8116b48e8
-key: keys_H6H2ELFfMMo4X0tqBHPkuO
+id: keys-3.11-b9b33b5e3167a9e52eac8339532d5b75
+key: keys_3wp9cDyECXQD3hcwjBmNdu
 license: BSD3
 copyright: Copyright (C) 2011-2016 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,15 +21,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 library-dirs: /usr/lib/ghc-7.10.3/site-local/keys-3.11
 data-dir: /usr/share/arm-linux-ghc-7.10.3/keys-3.11
-hs-libraries: HSkeys-3.11-H6H2ELFfMMo4X0tqBHPkuO
+hs-libraries: HSkeys-3.11-3wp9cDyECXQD3hcwjBmNdu
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    comonad-5-e98e7adc8875accf64a86529d9aeae51
+    comonad-5-eb230ef163a26fe6410daceeb92d736a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    free-4.12.4-4d7b26d357ab46561e822913cd7a6493
+    free-4.12.4-5e68614777ed20792496ad931a527625
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
-    semigroupoids-5.0.1-53b0b3ecfca9d658a051ef7b22e11130
+    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
     semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
